# 1.0.1 (February 9, 2016)

* Private key files are now created with read permission for the owner only (`0600` mode).

* The README is now converted into reStructuredText for display in PyPI.

* Classified as Python 3 only in PyPI.

# 1.0.0 (February 6, 2016)

Initial release.
